pub struct DataUrl { /* private fields */ }Expand description
A URL using the “data” scheme, according to RFC2397.
Implementations
Sourceimpl DataUrl
impl DataUrl
Sourcepub const fn is_base64(&self) -> bool
pub const fn is_base64(&self) -> bool
Returns whether this DataUrl has its base64 flag set, e.g. “data:image/gif”.
Sourcepub fn encoded_data(&self) -> &str
pub fn encoded_data(&self) -> &str
Returns the string representation of the data encoded within this DataUrl.
Sourcepub fn media_type(&self) -> &str
pub fn media_type(&self) -> &str
Returns the string representation of the MIME type of the data encoded within this DataUrl. The returned string also contains the type’s parameters if any.
Notes
When a DataUrl omits the MIME type (e.g. “data:,A%20brief%20note”), this method returns the default MIME type “text/plain;charset=US-ASCII”, instead of the empty string.
Example